@@ -12,9 +12,13 @@ import (
 	quayv1 "github.com/quay/quay-bridge-operator/api/v1"
 	"github.com/quay/quay-bridge-operator/pkg/constants"
 	"github.com/quay/quay-bridge-operator/pkg/logging"
+	qotypes "github.com/quay/quay-bridge-operator/pkg/types"
+	"github.com/quay/quay-bridge-operator/pkg/utils"
 	jsonpatch "gomodules.xyz/jsonpatch/v2"
 	admissionv1 "k8s.io/api/admission/v1"
+	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/types"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/webhook/admission"
 )
@@ -55,8 +59,28 @@ func (q *QuayIntegrationMutator) Handle(ctx context.Context, req admission.Reque
 			}
 		}
 	} else {
+		// Check if builder service account has secret
+		hasSecret, serviceAcctErr := q.checkSecretForBuilderServiceAccount(ctx, &req, &quayIntegration)
 
-		admissionResponse = getAdmissionResponseForBuild(build, &quayIntegration)
+		if !hasSecret {
+			if serviceAcctErr != nil {
+				admissionResponse = &admissionv1.AdmissionResponse{
+					Allowed: false,
+					Result: &metav1.Status{
+						Message: serviceAcctErr.Error(),
+					},
+				}
+			} else {
+				admissionResponse = &admissionv1.AdmissionResponse{
+					Allowed: false,
+					Result: &metav1.Status{
+						Message: "The builder service account has not been provisioned with secrets yet",
+					},
+				}
+			}
+		} else {
+			admissionResponse = getAdmissionResponseForBuild(build, &quayIntegration)
+		}
 
 	}
 
@@ -64,6 +88,22 @@ func (q *QuayIntegrationMutator) Handle(ctx context.Context, req admission.Reque
 
 }
 
+func (q *QuayIntegrationMutator) checkSecretForBuilderServiceAccount(ctx context.Context, ar *admission.Request, quayIntegration *quayv1.QuayIntegration) (bool, error) {
+	builderServiceAccnt := &corev1.ServiceAccount{}
+
+	err := q.Client.Get(ctx, types.NamespacedName{Namespace: ar.Namespace, Name: string(qotypes.BuilderOpenShiftServiceAccount)}, builderServiceAccnt)
+	if err != nil {
+		logging.Log.Info("Failed to get existing builder service account in", "Namespace", ar.Namespace)
+		return false, err
+	}
+
+	hasSecret := utils.ObjectReferenceNameExists(builderServiceAccnt.Secrets, utils.GenerateDockerJsonSecretNameForServiceAccount(builderServiceAccnt.ObjectMeta.Name, quayIntegration.Spec.ClusterID))
+	if !hasSecret {
+		logging.Log.Info("Builder service account does not have required secret")
+	}
+	return hasSecret, nil
+}
+
 func (q *QuayIntegrationMutator) getQuayIntegration(ctx context.Context, ar *admission.Request) (quayv1.QuayIntegration, bool, error) {
 
 	// Find the Current Registered QuayIntegration objects
@@ -129,6 +169,14 @@ func getAdmissionResponseForBuild(build *buildv1.Build, quayIntegration *quayv1.
 		Value:     dockerImage,
 	})
 
+	// Remove the namespace attribute
+	if build.Spec.CommonSpec.Output.To.Namespace != "" {
+		patch = append(patch, jsonpatch.JsonPatchOperation{
+			Operation: "remove",
+			Path:      "/spec/output/to/namespace",
+		})
+	}
+
 	// Add annotations to Build to for Build Controller to use
 	patch = append(patch, jsonpatch.JsonPatchOperation{
 		Operation: "add",
